@@ -24,13 +24,16 @@ from dataclasses import asdict
 from functools import lru_cache
 from typing import TYPE_CHECKING, Any
 
-import cpuinfo
 import numpy as np
 import platformdirs
+import requests
 
 import blosc2
 from blosc2 import blosc2_ext
 
+if not blosc2.IS_WASM:
+    import cpuinfo
+
 if TYPE_CHECKING:
     from collections.abc import Callable
 
@@ -1118,6 +1121,12 @@ def print_versions():
     print("Main codec library versions:")
     for clib in sorted(clib_versions.keys()):
         print(f"  {clib}: {clib_versions[clib]}")
+    print(f"NumPy version: {np.__version__}")
+    if not blosc2.IS_WASM:
+        import numexpr
+
+        print(f"numexpr version: {numexpr.__version__}")
+    print(f"requests version: {requests.__version__}")
     print(f"Python version: {sys.version}")
     (sysname, _nodename, release, version, machine, processor) = platform.uname()
     print(f"Platform: {sysname}-{release}-{machine} ({version})")
@@ -1125,6 +1134,8 @@ def print_versions():
         distro = os_release_pretty_name()
         if distro:
             print(f"Linux dist: {distro}")
+    if blosc2.IS_WASM:
+        processor = "wasm32"
     if not processor:
         processor = "not recognized"
     print(f"Processor: {processor}")
@@ -1201,6 +1212,17 @@ def linux_cache_size(cache_level: int, default_size: int) -> int:
 
 
 def _get_cpu_info():
+    if blosc2.IS_WASM:
+        # Emscripten/wasm32 does not have access to CPU information.
+        # Populate it with some reasonable defaults.
+        return {
+            "brand": "Emscripten",
+            "arch": "wasm32",
+            "count": 1,
+            "l1_data_cache_size": 32 * 1024,
+            "l2_cache_size": 256 * 1024,
+            "l3_cache_size": 1024 * 1024,
+        }
     cpu_info = cpuinfo.get_cpu_info()
     # cpuinfo does not correctly retrieve the cache sizes for Apple Silicon, so do it manually
     if platform.system() == "Darwin":
@@ -1327,6 +1349,27 @@ def get_chunksize(blocksize, l3_minimum=4 * 2**20, l3_maximum=2**26):
 
 
 def nearest_divisor(a, b, strict=False):
+    """Find the divisor of `a` that is closest to `b`.
+
+    Parameters
+    ----------
+    a : int
+        The number for which to find divisors.
+    b : int
+        The reference value to compare divisors against.
+    strict : bool, optional
+        If True, always use the downward search algorithm.
+
+    Returns
+    -------
+    int
+        The divisor of `a` that is closest to `b`.
+
+    Notes
+    -----
+    There is a version of this function in the Cython extension module
+    that is *way* faster.
+    """
     if a > 100_000 or strict:
         # When `a` is largish, or we require `b` strictly less than `a`,
         # use a (faster) algorithm that only goes downwards.
@@ -1334,6 +1377,7 @@ def nearest_divisor(a, b, strict=False):
         for i in range(b, 0, -1):
             if a % i == 0:
                 return i
+        return 1  # Fallback to 1, which is always a divisor
 
     # When `a` is smallish, use a more general algorithm that can find forwards and backwards
     # Get all divisors of `a`; use a generator to avoid creating a list
@@ -1368,11 +1412,13 @@ def compute_partition(nitems, maxshape, minpart=None):
             break
         rsize = max(size, minsize)
         if rsize <= max_items:
-            rsize = rsize if size % rsize == 0 else nearest_divisor(size, rsize)
+            # rsize = rsize if size % rsize == 0 else nearest_divisor(size, rsize)
+            rsize = rsize if size % rsize == 0 else blosc2_ext.nearest_divisor(size, rsize)
             partition[-(i + 1)] = rsize
         else:
             rsize = max(max_items, minsize)
-            new_rsize = rsize if size % rsize == 0 else nearest_divisor(size, rsize, strict=True)
+            # new_rsize = rsize if size % rsize == 0 else nearest_divisor(size, rsize, strict=True)
+            new_rsize = rsize if size % rsize == 0 else blosc2_ext.nearest_divisor(size, rsize, strict=True)
             # If the new rsize is not too far from the original rsize, use it
             if rsize // 2 < new_rsize < rsize * 2:
                 rsize = new_rsize
